@@ -3,16 +3,16 @@
  * Copyright (C) 2002 The libgnomecanvasmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -110,7 +110,7 @@ Features::on_item_event(GdkEvent* event,
       return false;
   }
   
-  if(item->get_parent_group() == m_parent1) {
+  if(item->property_parent().get_value() == m_parent1) {
       item->reparent(*m_parent2);
   } else {
       item->reparent(*m_parent1);
